@@ -3,12 +3,10 @@ package YAML::PP::LibYAML::Parser;
 use strict;
 use warnings;
 
-our $VERSION = '0.002_001'; # TRIAL VERSION
+our $VERSION = '0.001'; # VERSION
 
 use YAML::LibYAML::API::XS;
 use YAML::PP::Reader;
-use Scalar::Util qw/ openhandle /;
-
 use base 'YAML::PP::Parser';
 
 sub new {
@@ -34,19 +32,9 @@ sub set_reader {
 sub parse {
     my ($self) = @_;
     my $reader = $self->reader;
+    my $yaml = $reader->read;
     my $events = [];
-    if ($reader->can('open_handle')) {
-        if (openhandle($reader->input)) {
-            my $test = YAML::LibYAML::API::XS::parse_filehandle_events($reader->open_handle, $events);
-        }
-        else {
-            my $test = YAML::LibYAML::API::XS::parse_file_events($reader->input, $events);
-        }
-    }
-    else {
-        my $yaml = $reader->read;
-        my $test = YAML::LibYAML::API::XS::parse_string_events($yaml, $events);
-    }
+    my $test = YAML::LibYAML::API::XS::parse_events($yaml, $events);
     for my $info (@$events) {
         my $name = $info->{name};
         $self->callback->( $self, $name => $info );
